/*
 * Copyright (C) 1999  Jesse E. Peterson
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *
 */

import java.io.IOException;
import java.net.DatagramPacket;
import java.net.InetAddress;
import java.net.MulticastSocket;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * Simple client that listens for UDP broadcast messages. When a broadcast
 * message is received, it is printed to standard out.
 */
public class MulticastListener
{
    static final SimpleDateFormat timestamp = new SimpleDateFormat("yyyy/MM/dd HH:mm:ss");

    /**
     * Start a client listening for UDP multicast messages on port 4378 for
     * multicast group 239.6.20.71, the default values for the X10Server.
     */
    public static void main(String[] args)
    {
        try
        {
            DatagramPacket packet;
            InetAddress group = InetAddress.getByName("239.6.20.71");
            MulticastSocket socket = new MulticastSocket(4378);
            socket.joinGroup(group);

            while (true)
            {
                byte[] buf = new byte[1000];
                packet = new DatagramPacket(buf, buf.length);

                socket.receive(packet);

                String received = new String(packet.getData());
                System.out.println("X10 Message [" + timestamp.format(new Date()) + "]: " + received.trim());
            }
        }
        catch (Exception e)
        {
            e.printStackTrace();
            System.exit(1);
        }
    }
}
