/*
 * Copyright (C) 2000  Jesse E. Peterson
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *
 */

package java.text;

/**
 * Implemented to support unsupported methods within TINI.<p>
 * <code>ParsePosition</code> is a simple class used by <code>Format</code>
 * and its subclasses to keep track of the current position during parsing.
 * The <code>parseObject</code> method in the various <code>Format</code>
 * classes requires a <code>ParsePosition</code> object as an argument.
 * By design, as you parse through a string with different formats, you can
 * use the same <code>ParsePosition</code>, since the index parameter records
 * the current position.
 *
 * @see Format
 */
public class ParsePosition extends Object
{
    int index;

    /**
     * Create a new ParsePosition with the given initial index.
     */
    public ParsePosition(int index)
    {
        this.index = index;
    }

    /**
     Retrieve the current parse position. On input to a parse method, this is
     * the index of the character at which parsing will begin; on output, it
     * is the index of the character following the last character parsed.
     */
    public int getIndex()
    {
        return(index);
    }

    /**
     * Set the current parse position.
     */
    public void setIndex(int index)
    {
    }
}
